package com.javaproxy;

import java.io.IOException;

/* JADX INFO: Access modifiers changed from: package-private */
/* compiled from: XmlManifestReader.java */
/* loaded from: com_javaproxy.jar:com/javaproxy/StringBlock.class */
public class StringBlock {
    private int[] m_stringOffsets;
    private int[] m_strings;
    private int[] m_styleOffsets;
    private int[] m_styles;
    private static final int CHUNK_TYPE = 1835009;

    public static StringBlock read(IntReader reader) throws IOException {
        XmlResourceParser.readCheckType(reader, CHUNK_TYPE);
        int chunkSize = reader.readInt();
        int stringCount = reader.readInt();
        int styleOffsetCount = reader.readInt();
        reader.readInt();
        int stringsOffset = reader.readInt();
        int stylesOffset = reader.readInt();
        StringBlock block = new StringBlock();
        block.m_stringOffsets = reader.readIntArray(stringCount);
        if (styleOffsetCount != 0) {
            block.m_styleOffsets = reader.readIntArray(styleOffsetCount);
        }
        int size = (stylesOffset == 0 ? chunkSize : stylesOffset) - stringsOffset;
        if (size % 4 != 0) {
            throw new IOException("String data size is not multiple of 4 (" + size + ").");
        }
        block.m_strings = reader.readIntArray(size / 4);
        if (stylesOffset != 0) {
            int size2 = chunkSize - stylesOffset;
            if (size2 % 4 != 0) {
                throw new IOException("Style data size is not multiple of 4 (" + size2 + ").");
            }
            block.m_styles = reader.readIntArray(size2 / 4);
        }
        return block;
    }

    public int getCount() {
        if (this.m_stringOffsets != null) {
            return this.m_stringOffsets.length;
        }
        return 0;
    }

    public String getString(int index) {
        if (index < 0 || this.m_stringOffsets == null || index >= this.m_stringOffsets.length) {
            return null;
        }
        int offset = this.m_stringOffsets[index];
        int length = getShort(this.m_strings, offset);
        StringBuilder result = new StringBuilder(length);
        while (length != 0) {
            offset += 2;
            result.append((char) getShort(this.m_strings, offset));
            length--;
        }
        return result.toString();
    }

    public CharSequence get(int index) {
        return getString(index);
    }

    public String getHTML(int index) {
        String raw = getString(index);
        if (raw == null) {
            return raw;
        }
        int[] style = getStyle(index);
        if (style == null) {
            return raw;
        }
        StringBuilder html = new StringBuilder(raw.length() + 32);
        int offset = 0;
        while (true) {
            int i = -1;
            for (int j = 0; j != style.length; j += 3) {
                if (style[j + 1] != -1 && (i == -1 || style[i + 1] > style[j + 1])) {
                    i = j;
                }
            }
            int start = i != -1 ? style[i + 1] : raw.length();
            for (int j2 = 0; j2 != style.length; j2 += 3) {
                int end = style[j2 + 2];
                if (end != -1 && end < start) {
                    if (offset <= end) {
                        html.append((CharSequence) raw, offset, end + 1);
                        offset = end + 1;
                    }
                    style[j2 + 2] = -1;
                    html.append('<');
                    html.append('/');
                    html.append(getString(style[j2]));
                    html.append('>');
                }
            }
            if (offset < start) {
                html.append((CharSequence) raw, offset, start);
                offset = start;
            }
            if (i != -1) {
                html.append('<');
                html.append(getString(style[i]));
                html.append('>');
                style[i + 1] = -1;
            } else {
                return html.toString();
            }
        }
    }

    public int find(String string) {
        if (string == null) {
            return -1;
        }
        for (int i = 0; i != this.m_stringOffsets.length; i++) {
            int offset = this.m_stringOffsets[i];
            int length = getShort(this.m_strings, offset);
            if (length == string.length()) {
                int j = 0;
                while (j != length) {
                    offset += 2;
                    if (string.charAt(j) != getShort(this.m_strings, offset)) {
                        break;
                    }
                    j++;
                }
                if (j == length) {
                    return i;
                }
            }
        }
        return -1;
    }

    private StringBlock() {
    }

    private int[] getStyle(int index) {
        if (this.m_styleOffsets == null || this.m_styles == null || index >= this.m_styleOffsets.length) {
            return null;
        }
        int offset = this.m_styleOffsets[index] / 4;
        int count = 0;
        for (int i = offset; i < this.m_styles.length && this.m_styles[i] != -1; i++) {
            count++;
        }
        if (count == 0 || count % 3 != 0) {
            return null;
        }
        int[] style = new int[count];
        int i2 = offset;
        int j = 0;
        while (i2 < this.m_styles.length && this.m_styles[i2] != -1) {
            int i3 = j;
            j++;
            int i4 = i2;
            i2++;
            style[i3] = this.m_styles[i4];
        }
        return style;
    }

    private static final int getShort(int[] array, int offset) {
        int value = array[offset / 4];
        if ((offset % 4) / 2 == 0) {
            return value & 65535;
        }
        return value >>> 16;
    }
}
